CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
72 lines
2.4 KiB
C++
72 lines
2.4 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip/device_functions.h>
|
|
#define LEN 512
|
|
#define SIZE (LEN << 2)
|
|
__global__ static void kernel_trig(float* In, float* sin_d, float* cos_d, float* tan_d,
|
|
float* sin_pd, float* cos_pd) {
|
|
int tid = threadIdx.x + blockIdx.x * blockDim.x;
|
|
sin_d[tid] = sinf(In[tid]);
|
|
cos_d[tid] = cosf(In[tid]);
|
|
tan_d[tid] = tanf(In[tid]);
|
|
sincosf(In[tid], &sin_pd[tid], &cos_pd[tid]);
|
|
}
|
|
HIP_TEST_CASE(Unit_kernel_trigger) {
|
|
float *In, *sin_h, *cos_h, *tan_h, *sin_ph, *cos_ph;
|
|
float *In_d, *sin_d, *cos_d, *tan_d, *sin_pd, *cos_pd;
|
|
int errors = 0;
|
|
In = new float[LEN];
|
|
sin_h = new float[LEN];
|
|
cos_h = new float[LEN];
|
|
tan_h = new float[LEN];
|
|
sin_ph = new float[LEN];
|
|
cos_ph = new float[LEN];
|
|
for (int i = 0; i < LEN; i++) {
|
|
In[i] = 1.0f;
|
|
sin_h[i] = 0.0f;
|
|
cos_h[i] = 0.0f;
|
|
tan_h[i] = 0.0f;
|
|
sin_ph[i] = 0.0f;
|
|
cos_ph[i] = 0.0f;
|
|
}
|
|
HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&In_d), SIZE));
|
|
HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&sin_d), SIZE));
|
|
HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&cos_d), SIZE));
|
|
HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&tan_d), SIZE));
|
|
HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&sin_pd), SIZE));
|
|
HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&cos_pd), SIZE));
|
|
|
|
HIP_CHECK(hipMemcpy(In_d, In, SIZE, hipMemcpyHostToDevice));
|
|
hipLaunchKernelGGL(kernel_trig, dim3(LEN, 1, 1), dim3(1, 1, 1), 0, 0, In_d, sin_d, cos_d, tan_d,
|
|
sin_pd, cos_pd);
|
|
HIP_CHECK(hipMemcpy(sin_h, sin_d, SIZE, hipMemcpyDeviceToHost));
|
|
HIP_CHECK(hipMemcpy(cos_h, cos_d, SIZE, hipMemcpyDeviceToHost));
|
|
HIP_CHECK(hipMemcpy(tan_h, tan_d, SIZE, hipMemcpyDeviceToHost));
|
|
HIP_CHECK(hipMemcpy(sin_ph, sin_pd, SIZE, hipMemcpyDeviceToHost));
|
|
HIP_CHECK(hipMemcpy(cos_ph, cos_pd, SIZE, hipMemcpyDeviceToHost));
|
|
// Validation
|
|
for (int i = 0; i < LEN; i++) {
|
|
if (sin_h[i] != sin_ph[i] || cos_h[i] != cos_ph[i] || tan_h[i] * cos_h[i] != sin_h[i]) {
|
|
errors++;
|
|
}
|
|
}
|
|
REQUIRE(errors == 0);
|
|
delete[] In;
|
|
delete[] sin_h;
|
|
delete[] cos_h;
|
|
delete[] tan_h;
|
|
delete[] sin_ph;
|
|
delete[] cos_ph;
|
|
HIP_CHECK(hipFree(In_d));
|
|
HIP_CHECK(hipFree(sin_d));
|
|
HIP_CHECK(hipFree(cos_d));
|
|
HIP_CHECK(hipFree(tan_d));
|
|
HIP_CHECK(hipFree(sin_pd));
|
|
HIP_CHECK(hipFree(cos_pd));
|
|
}
|